Name:		pcb
Version:	4.0.0
Release:	%mkrel 1
Summary:	An interactive printed circuit board editor
License:	GPLv2
Group:		Sciences/Other
URL:		http://pcb.sourceforge.net
Source0:	https://downloads.sourceforge.net/project/%{name}/%{name}/%{name}-%{version}/%{name}-%{version}.tar.gz
# Use upstream release versioning which is < date used previously
Epoch:		1

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gerbv
BuildRequires:	gettext >= 0.16.0
BuildRequires:	imagemagick
BuildRequires:	intltool >= 0.35.0
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gdlib)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(gtkglext-1.0) 
BuildRequires:	texinfo >= 4.6
BuildRequires:	texinfo-tex
BuildRequires:	tk

Requires:	m4

%description
PCB is an interactive printed circuit board editor.
PCB includes a rats nest feature, design rule checking, and can provide
industry standard RS-274-X (Gerber), NC drill, and centroid data (X-Y data)
output for use in the board fabrication and assembly process. PCB offers
high end features such as an autorouter and trace optimizer which can
tremendously reduce layout time.

%prep
%setup -q

%{__sed} -i \
   's|examplesdir = $(pkgdatadir)/examples|examplesdir = @docdir@/examples|' \
   example/libraries/Makefile.*

%{__sed} -i \
   's|tutdir = $(pkgdatadir)/tutorial|tutdir = @docdir@/tutorial|' \
   tutorial/Makefile.*

%build
## TODO Remove --disable-dependency-tracking if 
# https://bugs.launchpad.net/pcb/+bug/1661348 gets fixed
%configure \
	--disable-dependency-tracking \
	--with-gui=gtk \
	--enable-dbus \
	--enable-toporouter \
	--disable-update-mime-database \
	--disable-update-desktop-database \
	--docdir=%{_docdir}/%{name}-%{version}

%make_build

%install
%make_install

desktop-file-install \
    --dir %{buildroot}%{_datadir}/applications \
    --remove-category Engineering \
    --remove-category Electronics \
    --add-category Science \
    --add-category Engineering \
    --add-category Electronics \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

#
# Additional Examples
#
set +x
dest=%{buildroot}%{_docdir}/%{name}-%{version}/examples
for d in thermal pad puller ; do
   echo -n -e "... Fixing path of $d  \t"
   mkdir -p $dest/$d
   mv $dest/../$d.* $dest/$d
   install -pm 0644 doc/$d.{pcb,pdf} $dest/$d
   sed -i "s|$d.png|examples/$d/$d.png|" $dest/../%{name}.html
   echo "done"
done
set -x

## --- pcb supports for acpcircuits
# http://www.apcircuits.com/resources/links/pcb_unix.html
unzip tools/apctools.zip
install -p -m 755 apc*.pl  %{buildroot}%{_datadir}/%{name}/tools

# Removes duplicates
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/apctools.zip

# Old versions of PCB don't support autoroute, pcb2ncap convert
# pcb format to ncap format used for mucspcb to autoroute the circuit.
# In newer versions of PCB, autoroute is included and pcb2ncap and mucspcb
# are no more needed.
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/pcb2ncap.tgz

chmod 755 %{buildroot}%{_datadir}/%{name}/tools/{PCB2HPGL,tgo2pcb.tcl,Merge*}

cp -p AUTHORS COPYING README NEWS ChangeLog README_FILES/CHANGES \
      README_FILES/Whats_new_in_2.0 README_FILES/Tools \
      %{buildroot}%{_docdir}/%{name}-%{version}/

%{__rm} -rf %{buildroot}%{_datadir}/info/dir

mv %{buildroot}%{_docdir}/%{name}-%{version}/refcard.pdf %{buildroot}%{_docdir}/%{name}-%{version}/pcb-reference-card.pdf

# remove duplicates
%{__rm} -f %{buildroot}%{_bindir}/Merge*

# L#854396 0.20110918 needlessly installs gts static library & header file
%{__rm} -f %{buildroot}%{_libdir}/libgts.a %{buildroot}%{_includedir}/gts.h

%find_lang %{name}

%check

# Last test fails (no display available) so don't let it break build
%make check ||:

%files -f %{name}.lang
%doc %{_docdir}/%{name}-%{version}/*
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_datadir}/gEDA/scheme/*
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*
%{_infodir}/%{name}.info*
%{_iconsdir}/hicolor/*/mimetypes/application-x-*
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_datadir}/appdata/*
%{_datadir}/mime/packages/pcb.xml
%{_datadir}/mimelnk/application/x-*.desktop


%changelog
* Fri Feb 03 2017 barjac <barjac> 1:4.0.0-1.mga6
+ Revision: 1084639
- new version 4.0.0
- add Epoch to allow real upstream versioning
- remove patch merged upstream (finally after 5 years!)
- remove desktop file patch and use desktop-file-install
- update BRs
- fix build - bug filed upstream
- don_t let one failed test (expected) break build
- update Source0
-  use %%make_build %%make_install

* Tue Feb 09 2016 umeabot <umeabot> 20140316-6.mga6
+ Revision: 952315
- Mageia 6 Mass Rebuild

* Mon Feb 16 2015 oden <oden> 20140316-5.mga5
+ Revision: 815160
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 20140316-4.mga5
+ Revision: 747365
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 20140316-3.mga5
+ Revision: 725153
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 20140316-2.mga5
+ Revision: 683364
- Mageia 5 Mass Rebuild

* Fri Jul 11 2014 juergen_harms <juergen_harms> 20140316-1.mga5
+ Revision: 651282
- Add missing BuildRequires
- New stable upstream version, drop obsolete patches

* Sat Oct 19 2013 umeabot <umeabot> 20110918-4.mga4
+ Revision: 523998
- Mageia 4 Mass Rebuild

* Thu Jan 24 2013 juergen_harms <juergen_harms> 20110918-3.mga4
+ Revision: 391763
- Introduce Internationalisation patch for gerber output
- Bump release

* Sun Jan 13 2013 umeabot <umeabot> 20110918-2.mga3
+ Revision: 362635
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 25 2012 dams <dams> 20110918-1.mga3
+ Revision: 309966
- update/fix %%group
- new snapshot 20110918
- clean specfile
- add upstream patches to fix issues
- add a patch to fix .desktop

* Sun Mar 04 2012 wally <wally> 20100929-5.mga2
+ Revision: 217847
- clean BRs
- clean .spec a bit

* Sat Mar 03 2012 wally <wally> 20100929-4.mga2
+ Revision: 217362
- add post and preun scripts for info files

* Fri Mar 02 2012 juergen_harms <juergen_harms> 20100929-3.mga2
+ Revision: 216732
- revert to revision 210024 (pcb-20100929-1.mga-2), but
  +   bump release
  +   correct libcanberra0 dependency
- correct libcanberra dependency to %%{_lib}canberra0
- suppress building info files (drop post and preun, texinfo and texlive again)
- add BuildRequires texlive (for makeinfo)
- add BuildRequires texinfo (for makeinfo)
- add preun and post clauses (info install and remove)
- temporary fix to correct FSF addresses (prep section)

* Fri Feb 17 2012 juergen_harms <juergen_harms> 20100929-1.mga2
+ Revision: 210024
- import upstream releas 20100929
- correct source URL at sourceforge
- drop patches obsoleted by upstream development
- add missing files in %%files section:
  + MergePCBPS
  + Merge_dimPCBPS
  + gEDA/scheme/
- add dependency on libcanberra-gtk0
- imported package pcb

